@@ -8,12 +8,11 @@ IFS='/:' read -ra args <<< "$1"
 image="${args[1]}"
 
 if [ "${#args[@]}" -gt 2 ]; then
-    target="posix/ci/group${args[2]}/"
+    target="shippable/posix/group${args[2]}/"
 else
-    target="posix/ci/"
+    target="shippable/posix/"
 fi
 
 # shellcheck disable=SC2086
 ansible-test integration --color -v --retry-on-error "${target}" ${COVERAGE:+"$COVERAGE"} ${CHANGED:+"$CHANGED"} ${UNSTABLE:+"$UNSTABLE"} \
-    --exclude "posix/ci/cloud/" \
     --docker "${image}"
